@@ -6,7 +6,7 @@
 //
 // Copyright 2013, 2014 Igalia S.L.
 // Copyright 2014 Luigi Scarso <luigi.scarso@gmail.com>
-// Copyright 2014, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright 2014, 2018, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 //========================================================================
@@ -159,7 +159,7 @@ public:
 
   int getMCID() const { return c->mcid; }
   Ref getObjectRef() const { return c->ref; }
-  Ref getParentRef() { return isContent() ? parent->getParentRef() : s->parentRef.getRef(); }
+  Ref getParentRef() { return isContent() ? parent->getParentRef() : s->parentRef; }
   bool hasPageRef() const;
   bool getPageRef(Ref& ref) const;
   StructTreeRoot *getStructTreeRoot() { return treeRoot; }
@@ -253,7 +253,7 @@ private:
   typedef std::vector<StructElement*> ElemPtrArray;
 
   struct StructData {
-    Object       parentRef;
+    Ref         parentRef;
     GooString   *altText;
     GooString   *actualText;
     GooString   *id;
@@ -298,7 +298,7 @@ private:
   StructElement(const Ref ref, StructTreeRoot *treeRootA, StructElement *parentA);
 
   void parse(Dict* elementDict);
-  StructElement* parseChild(Object *ref, Object* childObj, std::set<int> &seen);
+  StructElement* parseChild(const Object *ref, Object* childObj, std::set<int> &seen);
   void parseChildren(Dict* element, std::set<int> &seen);
   void parseAttributes(Dict *element, bool keepExisting = false);
 
